import numpy as np
import matplotlib.pyplot as plt

def generate_prism_array(pitch, orientation, size):
    x = np.arange(size[0])
    y = np.arange(size[1])
    xx, yy = np.meshgrid(x, y)
    return np.sin(2 * np.pi * (xx * np.cos(orientation) + yy * np.sin(orientation)) / pitch)

def simulate_moire_pattern(pitch1, pitch2, orientation1, orientation2, size):
    array1 = generate_prism_array(pitch1, orientation1, size)
    array2 = generate_prism_array(pitch2, orientation2, size)
    moire_pattern = array1 + array2

    plt.imshow(moire_pattern, cmap='gray')
    plt.axis('off')
    plt.show()

# Parameters for the Moire pattern simulation
pitch1 = 50  # Pitch of the first prism array
pitch2 = 70  # Pitch of the second prism array
orientation1 = np.pi / 4  # Orientation of the first prism array (in radians)
orientation2 = np.pi / 6  # Orientation of the second prism array (in radians)
size = (400, 400)  # Size of the Moire pattern

# Simulate and display the Moire pattern
simulate_moire_pattern(pitch1, pitch2, orientation1, orientation2, size)
